<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DNAStatMSAProfileDialog</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="14"/>
        <source>Generate Alignment Profile</source>
        <translation>Генерация сеточного отчета для выравнивания</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="20"/>
        <source>Profile mode</source>
        <translation>Использовать</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="26"/>
        <source>Count</source>
        <translation>Число</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="36"/>
        <source>Percentage</source>
        <translation>Процент</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="46"/>
        <source>Custom options</source>
        <translation>Дополнительные опции</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="52"/>
        <source>Show scores for gaps</source>
        <translation>Включить в отчет статистику для пробелов</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="59"/>
        <source>Show scores for symbols not used in alignment</source>
        <translation>Включить в отчет неиспользуемые символы</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="66"/>
        <source>Skip gaps in consensus position increments</source>
        <translation>Не учитывать пробелы в шкале позиций</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="76"/>
        <source>Save profile to file</source>
        <translation>Сохранить отчет в файл</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="111"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="118"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="98"/>
        <source>Hypertext  (.HTML)</source>
        <translation>Гипертекст (.HTML)</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="88"/>
        <source>Comma separated ( .CSV)</source>
        <translation>Значения через запятую (.CSV)</translation>
    </message>
</context>
<context>
    <name>DistanceMatrixMSAProfileDialog</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="14"/>
        <source>Generate Distance Matrix</source>
        <translation>Рассчитать матрицу расстояний</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="22"/>
        <source>Distance algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="34"/>
        <source>Profile mode</source>
        <translation>Использовать</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="40"/>
        <source>Count</source>
        <translation>Число</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="50"/>
        <source>Percentage</source>
        <translation>Процент</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="57"/>
        <source>Exclude gaps</source>
        <translation>Исключить пробелы</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="67"/>
        <source>Show group statistics of multiple alignment</source>
        <translation>Показать групповую статистику множественного выравнивания</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="77"/>
        <source>Save profile to file</source>
        <translation>Сохранить отчет в файл</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="89"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="99"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="106"/>
        <source>Hypertext  (.HTML)</source>
        <translation>Гипертекст (.HTML)</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="116"/>
        <source>Comma separated ( .CSV)</source>
        <translation>Значения через запятую (.CSV)</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAEditorContext</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="73"/>
        <source>Generate grid profile...</source>
        <translation>Представить выравнивание в виде таблицы частот...</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAProfileDialog</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="56"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="89"/>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="118"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="118"/>
        <source>File URL is empty</source>
        <translation>Не указан файл для сохранения отчета</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="128"/>
        <source>&lt;b&gt;&lt;font color=%1&gt;%2&lt;/font&gt;&lt;br&gt;&lt;/br&gt;&lt;/b&gt;</source>
        <translation>&lt;b&gt;&lt;font color=%1&gt;%2&lt;/font&gt;&lt;br&gt;&lt;/br&gt;&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="130"/>
        <source>Warning: report is too big to be shown in UGENE.</source>
        <translation>Предупреждение: отчет слишком большой чтобы отобразить его в UGENE.</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAProfileTask</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="138"/>
        <source>Generate alignment profile</source>
        <translation>Генерация сеточного отчета</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="151"/>
        <source>No output file name specified</source>
        <translation>Не указано имя файла для сохранения отчета</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="188"/>
        <source>Alignment file:</source>
        <translation>Файл:</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="190"/>
        <source>Table content:</source>
        <translation>Результаты:</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="191"/>
        <source>symbol percents</source>
        <translation>процент символа</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="191"/>
        <source>symbol counts</source>
        <translation>количество символов</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="161"/>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="288"/>
        <source>Can&apos;t open file for write: %1</source>
        <translation>Не могу открыть файл для записи: %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="279"/>
        <source>There is not enough memory to show this grid profile in UGENE. You can save it to an HTML file and open it with a web browser.</source>
        <translation>There is not enough memory to show this grid profile in UGENE. You can save it to an HTML file and open it with a web browser.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="281"/>
        <source>There is not enough memory to generate this grid profile in UGENE.</source>
        <translation>There is not enough memory to generate this grid profile in UGENE.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="321"/>
        <source>Task was finished with an error: %1</source>
        <translation>Task was finished with an error: %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="324"/>
        <source>Task was canceled.</source>
        <translation>Task was canceled.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="328"/>
        <source>Grid profile for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</source>
        <translation>Grid profile for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="342"/>
        <source>Alignment profile</source>
        <translation>Отчет для множественного выравнивания</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="342"/>
        <source>Alignment profile for %1</source>
        <translation>Отчет для множественного выравнивания %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="185"/>
        <source>Multiple Sequence Alignment Grid Profile</source>
        <translation>Сеточный отчет для множественного выравнивания</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="261"/>
        <source>Legend:</source>
        <translation>Легенда:</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatPlugin</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="54"/>
        <source>DNA Statistics</source>
        <translation>ДНК статистика</translation>
    </message>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="54"/>
        <source>Provides statistical reports for sequences and alignments</source>
        <translation>Набор статистических отчетов</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAEditorContext</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="114"/>
        <source>Generate distance matrix...</source>
        <translation>Рассчитать матрицу расстояний...</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAProfileDialog</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="61"/>
        <source>Generate</source>
        <translation>Создать отчет</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="97"/>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="128"/>
        <source>File URL is empty</source>
        <translation>Не указан файл для сохранения отчета</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAProfileTask</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="153"/>
        <source>Generate distance matrix</source>
        <translation>Рассчитать матрицу расстояний</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="180"/>
        <source>No output file name specified</source>
        <translation>Не указано имя файла для сохранения отчета</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="203"/>
        <source>Multiple Sequence Alignment Distance Matrix</source>
        <translation>Матрица расстояний множественного выравнивания</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="206"/>
        <source>Alignment file:</source>
        <translation>Файл:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="207"/>
        <source>Table content:</source>
        <translation>Результаты:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="217"/>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="250"/>
        <source>There is not enough memory to show this distance matrix in UGENE. You can save it to an HTML file and open it with a web browser.</source>
        <translation>There is not enough memory to show this distance matrix in UGENE. You can save it to an HTML file and open it with a web browser.</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="224"/>
        <source>Group statistics of multiple alignment</source>
        <translation>Групповая статистика множественного выравнивания</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="257"/>
        <source>Legend:</source>
        <translation>Легенда:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="188"/>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="277"/>
        <source>Can&apos;t open file for write: %1</source>
        <translation>Не могу открыть файл для записи: %1</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="318"/>
        <source>There is not enough groups to create distance matrix!</source>
        <translation>Недостаточно групп для того, чтобы создать матрицу расстояний!</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="370"/>
        <source>Task was finished with an error: %1</source>
        <translation>Task was finished with an error: %1</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="374"/>
        <source>Distanse matrix for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</source>
        <translation>Distanse matrix for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="387"/>
        <source>Distance matrix</source>
        <translation>Матрица расстояний</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="387"/>
        <source>Distance matrix for %1</source>
        <translation>Матрица расстояний для %1</translation>
    </message>
</context>
</TS>
